# Keep imports sorted alphabetically
import fabtools.arch
import fabtools.cron
import fabtools.deb
import fabtools.disk
import fabtools.files
import fabtools.git
import fabtools.group
import fabtools.mysql
import fabtools.network
import fabtools.nginx
import fabtools.nodejs
import fabtools.openvz
import fabtools.oracle_jdk
import fabtools.pkg
import fabtools.postgres
import fabtools.python
import fabtools.python_distribute
import fabtools.rpm
import fabtools.service
import fabtools.shorewall
import fabtools.ssh
import fabtools.supervisor
import fabtools.system
import fabtools.user

import fabtools.require
icanhaz = require
